@@ -75,8 +75,16 @@ data_plot.bayestestR_eti <- data_plot.hdi
         dataplot$Effects <- NULL
         dataplot$Component <- NULL
       } else {
-        dataplot$Effects <- factor(dataplot$Effects, levels = sort(levels(dataplot$Effects)))
-        dataplot$Component <- factor(dataplot$Component, levels = sort(levels(dataplot$Component)))
+        if (is.factor(dataplot$Effects)) {
+          dataplot$Effects <- factor(dataplot$Effects, levels = sort(levels(dataplot$Effects)))
+        } else {
+          dataplot$Effects <- factor(dataplot$Effects, levels = unique(dataplot$Effects))
+        }
+        if (is.factor(dataplot$Component)) {
+          dataplot$Component <- factor(dataplot$Component, levels = sort(levels(dataplot$Component)))
+        } else {
+          dataplot$Component <- factor(dataplot$Component, levels = unique(dataplot$Component))
+        }
       }
     }
 
@@ -122,6 +130,7 @@ data_plot.bayestestR_eti <- data_plot.hdi
 #' @importFrom rlang .data
 #' @importFrom stats density
 #' @importFrom dplyr mutate arrange desc
+#' @importFrom magrittr "%>%"
 #' @keywords internal
 .compute_densities_hdi <- function(x, hdi, name = "Y"){
   hdi <- dplyr::arrange(hdi, dplyr::desc(.data$CI))
@@ -132,6 +141,9 @@ data_plot.bayestestR_eti <- data_plot.hdi
                   HDI_high = sapply(x, .classify_hdi, rev(hdi$CI_high), c(rev(hdi$CI), 100)),
                   fill = as.factor(ifelse(.data$HDI_low > .data$HDI_high, .data$HDI_low, .data$HDI_high)),
                   height = .data$y, y = name)
+
+  levels(out$fill) <- sprintf("%s%%", levels(out$fill))
+
   # normalize
   out$height <- as.vector((out$height - min(out$height, na.rm = TRUE)) / diff(range(out$height, na.rm = TRUE), na.rm = TRUE))
   out
